<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

namespace SGalinski\SgFormsPdf\Ajax;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use SGalinski\SgFormsPdf\Service\PdfService;
use TYPO3\CMS\Core\Http\Response;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility;

/**
 * Responsible for showing the finisher pdf after the user clisk on the link in the confirmation
 */
class PdfResponse {
	/**
	 * @param ServerRequestInterface $request
	 * @return ResponseInterface
	 */
	public function processRequest(ServerRequestInterface $request): ResponseInterface {
		$response = GeneralUtility::makeInstance(Response::class);
		$param = $request->getQueryParams();
		$pdfFilePath = '';

		if (isset($param['file']) && $param['file']) {
			$pdfFilePath = $param['file'];
		}

		if ($pdfFilePath && file_exists($pdfFilePath)) {
			header('Content-Type: application/pdf');
			header('Content-Disposition: inline; filename="' . PdfService::PDF_NAME . '"');
			header('Content-Length: ' . filesize($pdfFilePath));
			// output the pdf
			readfile($pdfFilePath);
			// delete the pdf
			unlink($pdfFilePath);
			exit;
		}

		$response->getBody()->write('<p>' . LocalizationUtility::translate('confirmationWithLink.error.file') . '</p>');

		return $response->withStatus(404);
	}

}
