<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

namespace SGalinski\SgFormsPdf\Finisher;

use TYPO3\CMS\Core\Context\Exception\AspectNotFoundException;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Form\Domain\Finishers\Exception\FinisherException;

/**
 * Confirmation Finisher class
 */
class ConfirmationFinisher extends \TYPO3\CMS\Form\Domain\Finishers\ConfirmationFinisher {

	/**
	 * Executes this finisher
	 *
	 * @see AbstractFinisher::execute()
	 * @return string
	 *
	 * @throws FinisherException
	 */
	protected function executeInternal(): string {
		$contentElementUid = $this->parseOption('contentElementUid');
		$typoscriptObjectPath = $this->parseOption('typoscriptObjectPath');
		$typoscriptObjectPath = is_string($typoscriptObjectPath) ? $typoscriptObjectPath : '';
		if (!empty($contentElementUid)) {
			$pathSegments = GeneralUtility::trimExplode('.', $typoscriptObjectPath);
			$lastSegment = array_pop($pathSegments);
			$setup = $this->typoScriptSetup;
			foreach ($pathSegments as $segment) {
				if (!array_key_exists($segment . '.', $setup)) {
					throw new FinisherException(
						sprintf('TypoScript object path "%s" does not exist', $typoscriptObjectPath),
						1489238980
					);
				}
				$setup = $setup[$segment . '.'];
			}
			$this->contentObjectRenderer->setRequest($this->finisherContext->getRequest());
			$this->contentObjectRenderer->start([$contentElementUid]);
			$this->contentObjectRenderer->setCurrentVal((string) $contentElementUid);
			$message = $this->contentObjectRenderer->cObjGetSingle(
				$setup[$lastSegment], $setup[$lastSegment . '.'], $lastSegment
			);
		} else {
			$message = $this->parseOption('message');
		}

		$standaloneView = $this->initializeStandaloneView(
			$this->finisherContext->getFormRuntime()
		);

		// extension start
		$tempPdfFile = '';
		$openPdfInNewWindow = $this->finisherContext->getFinisherVariableProvider()->get(
			PdfFinisher::FINISHER_NAME,
			PdfFinisher::OPEN_PDF_IN_NEW_WINDOW,
			FALSE
		);

		if ($openPdfInNewWindow) {
			/** @var \FPDM $finisherPdf */
			$tempPdfFile = $this->finisherContext->getFinisherVariableProvider()->get(
				PdfFinisher::FINISHER_NAME,
				PdfFinisher::FINISHER_PDF_PATH
			);
		}

		$context = GeneralUtility::makeInstance(\TYPO3\CMS\Core\Context\Context::class);
		try {
			$langId = $context->getPropertyFromAspect('language', 'id');
		} catch (AspectNotFoundException $e) {
			$langId = 0;
		}

		$standaloneView->assignMultiple([
			'message' => $message,
			'tempPdfFile' => $tempPdfFile,
			'isPreparedMessage' => !empty($contentElementUid),
			'langId' => $langId,
		]);

		// extension end
		return $standaloneView->render();
	}
}
